@@ -4,6 +4,7 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/goreleaser/goreleaser/internal/skips"
 	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/pkg/context"
 	"github.com/stretchr/testify/require"
@@ -66,21 +67,29 @@ func TestReleaseFlags(t *testing.T) {
 			snapshot: true,
 		})
 		require.True(t, ctx.Snapshot)
-		require.True(t, ctx.SkipPublish)
-		require.True(t, ctx.SkipValidate)
-		require.True(t, ctx.SkipAnnounce)
+		requireAll(t, ctx, skips.Publish, skips.Validate, skips.Announce)
 	})
 
-	t.Run("skips", func(t *testing.T) {
+	t.Run("skips (old)", func(t *testing.T) {
 		ctx := setup(t, releaseOpts{
 			skipPublish:  true,
 			skipSign:     true,
 			skipValidate: true,
 		})
-		require.True(t, ctx.SkipSign)
-		require.True(t, ctx.SkipPublish)
-		require.True(t, ctx.SkipValidate)
-		require.True(t, ctx.SkipAnnounce)
+
+		requireAll(t, ctx, skips.Sign, skips.Publish, skips.Validate, skips.Announce)
+	})
+
+	t.Run("skips", func(t *testing.T) {
+		ctx := setup(t, releaseOpts{
+			skips: []string{
+				string(skips.Publish),
+				string(skips.Sign),
+				string(skips.Validate),
+			},
+		})
+
+		requireAll(t, ctx, skips.Sign, skips.Publish, skips.Validate, skips.Announce)
 	})
 
 	t.Run("parallelism", func(t *testing.T) {
