@@ -6,6 +6,7 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/goreleaser/goreleaser/internal/skips"
 	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/config"
@@ -112,7 +113,7 @@ func TestDirty(t *testing.T) {
 		require.Contains(t, err.Error(), "git is in a dirty state")
 	})
 	t.Run("skip validate is set", func(t *testing.T) {
-		ctx := testctx.New(testctx.SkipValidate)
+		ctx := testctx.New(testctx.Skip(skips.Validate))
 		testlib.AssertSkipped(t, Pipe{}.Run(ctx))
 		require.True(t, ctx.Git.Dirty)
 	})
@@ -162,7 +163,7 @@ func TestShallowClone(t *testing.T) {
 		require.NoError(t, Pipe{}.Run(testctx.New()))
 	})
 	t.Run("skip validate is set", func(t *testing.T) {
-		ctx := testctx.New(testctx.SkipValidate)
+		ctx := testctx.New(testctx.Skip(skips.Validate))
 		testlib.AssertSkipped(t, Pipe{}.Run(ctx))
 	})
 	t.Run("snapshot", func(t *testing.T) {
@@ -358,3 +359,52 @@ func TestPreviousTagFromCI(t *testing.T) {
 		})
 	}
 }
+
+func TestFilterTags(t *testing.T) {
+	testlib.Mktmp(t)
+	testlib.GitInit(t)
+	testlib.GitRemoteAdd(t, "git@github.com:foo/bar.git")
+	testlib.GitCommit(t, "commit1")
+	testlib.GitTag(t, "v0.0.1")
+	testlib.GitCommit(t, "middle commit")
+	testlib.GitTag(t, "nightly")
+	testlib.GitCommit(t, "commit2")
+	testlib.GitCommit(t, "commit3")
+	testlib.GitTag(t, "v0.0.2")
+	testlib.GitTag(t, "v0.1.0-dev")
+
+	t.Run("no filter", func(t *testing.T) {
+		ctx := testctx.New()
+		require.NoError(t, Pipe{}.Run(ctx))
+		require.Equal(t, "nightly", ctx.Git.PreviousTag)
+		require.Equal(t, "v0.1.0-dev", ctx.Git.CurrentTag)
+	})
+
+	t.Run("template", func(t *testing.T) {
+		ctx := testctx.NewWithCfg(config.Project{
+			Git: config.Git{
+				IgnoreTags: []string{
+					"{{.Env.IGNORE}}",
+					"v0.0.2",
+					"nightly",
+				},
+			},
+		}, testctx.WithEnv(map[string]string{
+			"IGNORE": `v0.0.1`,
+		}))
+		require.NoError(t, Pipe{}.Run(ctx))
+		require.Empty(t, ctx.Git.PreviousTag)
+		require.Equal(t, "v0.1.0-dev", ctx.Git.CurrentTag)
+	})
+
+	t.Run("invalid template", func(t *testing.T) {
+		ctx := testctx.NewWithCfg(config.Project{
+			Git: config.Git{
+				IgnoreTags: []string{
+					"{{.Env.Nope}}",
+				},
+			},
+		})
+		testlib.RequireTemplateError(t, Pipe{}.Run(ctx))
+	})
+}
