@@ -11,7 +11,6 @@ import (
 	"strings"
 	"time"
 
-	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/internal/yaml"
 	"github.com/goreleaser/nfpm/v2/files"
 	"github.com/invopop/jsonschema"
@@ -19,8 +18,9 @@ import (
 
 // Git configs.
 type Git struct {
-	TagSort          string `yaml:"tag_sort,omitempty" json:"tag_sort,omitempty"`
-	PrereleaseSuffix string `yaml:"prerelease_suffix,omitempty" json:"prerelease_suffix,omitempty"`
+	TagSort          string   `yaml:"tag_sort,omitempty" json:"tag_sort,omitempty" jsonschema:"enum=-version:refname,enum=-version:creatordate,default=-version:refname"`
+	PrereleaseSuffix string   `yaml:"prerelease_suffix,omitempty" json:"prerelease_suffix,omitempty"`
+	IgnoreTags       []string `yaml:"ignore_tags,omitempty" json:"ignore_tags,omitempty"`
 }
 
 // GitHubURLs holds the URLs to be used when using github enterprise.
@@ -310,30 +310,36 @@ func (a *NixDependency) UnmarshalYAML(unmarshal func(interface{}) error) error {
 }
 
 type Winget struct {
-	Name                  string       `yaml:"name,omitempty" json:"name,omitempty"`
-	PackageIdentifier     string       `yaml:"package_identifier,omitempty" json:"package_identifier,omitempty"`
-	Publisher             string       `yaml:"publisher,omitempty" json:"publisher,omitempty"`
-	PublisherURL          string       `yaml:"publisher_url,omitempty" json:"publisher_url,omitempty"`
-	PublisherSupportURL   string       `yaml:"publisher_support_url,omitempty" json:"publisher_support_url,omitempty"`
-	Copyright             string       `yaml:"copyright,omitempty" json:"copyright,omitempty"`
-	CopyrightURL          string       `yaml:"copyright_url,omitempty" json:"copyright_url,omitempty"`
-	Author                string       `yaml:"author,omitempty" json:"author,omitempty"`
-	Path                  string       `yaml:"path,omitempty" json:"path,omitempty"`
-	Repository            RepoRef      `yaml:"repository,omitempty" json:"repository,omitempty"`
-	CommitAuthor          CommitAuthor `yaml:"commit_author,omitempty" json:"commit_author,omitempty"`
-	CommitMessageTemplate string       `yaml:"commit_msg_template,omitempty" json:"commit_msg_template,omitempty"`
-	IDs                   []string     `yaml:"ids,omitempty" json:"ids,omitempty"`
-	Goamd64               string       `yaml:"goamd64,omitempty" json:"goamd64,omitempty"`
-	SkipUpload            string       `yaml:"skip_upload,omitempty" json:"skip_upload,omitempty" jsonschema:"oneof_type=string;boolean"`
-	URLTemplate           string       `yaml:"url_template,omitempty" json:"url_template,omitempty"`
-	ShortDescription      string       `yaml:"short_description,omitempty" json:"short_description,omitempty"`
-	Description           string       `yaml:"description,omitempty" json:"description,omitempty"`
-	Homepage              string       `yaml:"homepage,omitempty" json:"homepage,omitempty"`
-	License               string       `yaml:"license,omitempty" json:"license,omitempty"`
-	LicenseURL            string       `yaml:"license_url,omitempty" json:"license_url,omitempty"`
-	ReleaseNotes          string       `yaml:"release_notes,omitempty" json:"release_notes,omitempty"`
-	ReleaseNotesURL       string       `yaml:"release_notes_url,omitempty" json:"release_notes_url,omitempty"`
-	Tags                  []string     `yaml:"tags,omitempty" json:"tags,omitempty"`
+	Name                  string             `yaml:"name,omitempty" json:"name,omitempty"`
+	PackageIdentifier     string             `yaml:"package_identifier,omitempty" json:"package_identifier,omitempty"`
+	Publisher             string             `yaml:"publisher,omitempty" json:"publisher,omitempty"`
+	PublisherURL          string             `yaml:"publisher_url,omitempty" json:"publisher_url,omitempty"`
+	PublisherSupportURL   string             `yaml:"publisher_support_url,omitempty" json:"publisher_support_url,omitempty"`
+	Copyright             string             `yaml:"copyright,omitempty" json:"copyright,omitempty"`
+	CopyrightURL          string             `yaml:"copyright_url,omitempty" json:"copyright_url,omitempty"`
+	Author                string             `yaml:"author,omitempty" json:"author,omitempty"`
+	Path                  string             `yaml:"path,omitempty" json:"path,omitempty"`
+	Repository            RepoRef            `yaml:"repository,omitempty" json:"repository,omitempty"`
+	CommitAuthor          CommitAuthor       `yaml:"commit_author,omitempty" json:"commit_author,omitempty"`
+	CommitMessageTemplate string             `yaml:"commit_msg_template,omitempty" json:"commit_msg_template,omitempty"`
+	IDs                   []string           `yaml:"ids,omitempty" json:"ids,omitempty"`
+	Goamd64               string             `yaml:"goamd64,omitempty" json:"goamd64,omitempty"`
+	SkipUpload            string             `yaml:"skip_upload,omitempty" json:"skip_upload,omitempty" jsonschema:"oneof_type=string;boolean"`
+	URLTemplate           string             `yaml:"url_template,omitempty" json:"url_template,omitempty"`
+	ShortDescription      string             `yaml:"short_description,omitempty" json:"short_description,omitempty"`
+	Description           string             `yaml:"description,omitempty" json:"description,omitempty"`
+	Homepage              string             `yaml:"homepage,omitempty" json:"homepage,omitempty"`
+	License               string             `yaml:"license,omitempty" json:"license,omitempty"`
+	LicenseURL            string             `yaml:"license_url,omitempty" json:"license_url,omitempty"`
+	ReleaseNotes          string             `yaml:"release_notes,omitempty" json:"release_notes,omitempty"`
+	ReleaseNotesURL       string             `yaml:"release_notes_url,omitempty" json:"release_notes_url,omitempty"`
+	Tags                  []string           `yaml:"tags,omitempty" json:"tags,omitempty"`
+	Dependencies          []WingetDependency `yaml:"dependencies,omitempty" json:"dependencies,omitempty"`
+}
+
+type WingetDependency struct {
+	PackageIdentifier string `yaml:"package_identifier" json:"package_identifier"`
+	MinimumVersion    string `yaml:"minimum_version,omitempty" json:"minimum_version,omitempty"`
 }
 
 // Krew contains the krew section.
@@ -682,7 +688,7 @@ type UniversalBinary struct {
 
 // UPX allows to compress binaries with `upx`.
 type UPX struct {
-	Enabled  bool     `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	Enabled  string   `yaml:"enabled,omitempty" json:"enabled,omitempty" jsonschema:"oneof_type=string;boolean"`
 	IDs      []string `yaml:"ids,omitempty" json:"ids,omitempty"`
 	Goos     []string `yaml:"goos,omitempty" json:"goos,omitempty"`
 	Goarch   []string `yaml:"goarch,omitempty" json:"goarch,omitempty"`
@@ -905,7 +911,7 @@ type SBOM struct {
 	Env       []string `yaml:"env,omitempty" json:"env,omitempty"`
 	Args      []string `yaml:"args,omitempty" json:"args,omitempty"`
 	Documents []string `yaml:"documents,omitempty" json:"documents,omitempty"`
-	Artifacts string   `yaml:"artifacts,omitempty" json:"artifacts,omitempty"`
+	Artifacts string   `yaml:"artifacts,omitempty" json:"artifacts,omitempty" jsonschema:"enum=source,enum=package,enum=archive,enum=binary,enum=any,enum=any,default=archive"`
 	IDs       []string `yaml:"ids,omitempty" json:"ids,omitempty"`
 }
 
@@ -1330,7 +1336,6 @@ func Load(file string) (config Project, err error) {
 		return
 	}
 	defer f.Close()
-	log.WithField("file", file).Info("loading config file")
 	return LoadReader(f)
 }
 
@@ -1341,7 +1346,6 @@ func LoadReader(fd io.Reader) (config Project, err error) {
 		return config, err
 	}
 	err = yaml.UnmarshalStrict(data, &config)
-	log.WithField("config", config).Debug("loaded config file")
 	return config, err
 }
 
